==> stefantools-1.4.tar.gz: stefantools-1.4/README.md <==
# StefanTools

## Description

This is a package that I use in my every project. I published it so I don't have to use *sys.path.append()* every time.

## Importing

Because of a class called "input", if you import this package using *from StefanTools import \** you will lose the ability to use *input()* in that file.

That's why you should **always** import this using *import StefanTools*.

## Maintaining

Because this is created for my personal use **don't expect any updating or maintaining** unless I need it or feel like it.

But, if you [want a new feature](https://github.com/PROStefi1000/StefanTools/issues/new?assignees=PROStefi1000&labels=enhancement&projects=&template=feature_request.md&title=) or [found a bug](https://github.com/PROStefi1000/StefanTools/issues/new?assignees=PROStefi1000&labels=bug&projects=&template=bug_report.md&title=), feel free to [open a new issue](https://github.com/PROStefi1000/StefanTools/issues/new/choose) on [the GitHub page](https://github.com/PROStefi1000/StefanTools).

## Things I'd like to clarify

These are some things I'd like to mention.

### You can't turn off text being displayed in the rich style

This package uses rich style text and errors which makes things look beautiful in my opinion. If you don't like it, don't use the package.

### Some functions are useless

#### Dependencies

Even though some things can be done without this package (for example the *format.number.text()* function) and instead through the use of [another package](https://pypi.org/project/inflect/), it's hard to remember which package to use to get the needed functionality so that's why some functions are just references to functions in other packages.

#### Useless functions

Some functions may be considered useless (the *fractions()* function will be an example) and that way of thinking is correct. This function just does the thing you can do in your own python file in a line of code but I think it's easier to just use *StefanTools.fractions()* function instead of writing the code yourself because it's easier to read and looks better in my opinion.

==> stefantools-1.4.1.tar.gz: stefantools-1.4.1/README.md <==
# StefanTools

## Description

This is a package that I use in my every project. I published it so I don't have to use *sys.path.append()* every time.

## Importing

Because of a class called "input", if you import this package using *from StefanTools import \** you will lose the ability to use *input()* in that file.

That's why you should **always** import this using *import StefanTools*.

## Maintaining

Because this is created for my personal use **don't expect any updating or maintaining** unless I need it or feel like it.

But, if you [want a new feature](https://github.com/PROStefi1000/StefanTools/issues/new?assignees=PROStefi1000&labels=enhancement&projects=&template=feature_request.md&title=) or [found a bug](https://github.com/PROStefi1000/StefanTools/issues/new?assignees=PROStefi1000&labels=bug&projects=&template=bug_report.md&title=), feel free to [open a new issue](https://github.com/PROStefi1000/StefanTools/issues/new/choose) on [the GitHub page](https://github.com/PROStefi1000/StefanTools).

## Things I'd like to clarify/mention

### Update logs

All update logs can be seen [here](https://github.com/PROStefi1000/StefanTools/releases).

### You can't turn off text being displayed in the rich style

This package uses rich style text and errors which makes things look beautiful in my opinion. If you don't like it, don't use the package.

### Some functions are useless

#### Dependencies

Even though some things can be done without this package (for example the *format.number.text()* function) and instead through the use of [another package](https://pypi.org/project/inflect/), it's hard to remember which package to use to get the needed functionality so that's why some functions are just references to functions in other packages.

#### Useless functions

Some functions may be considered useless (the *fractions()* function will be an example) and that way of thinking is correct. This function just does the thing you can do in your own python file in a line of code but I think it's easier to just use *StefanTools.fractions()* function instead of writing the code yourself because it's easier to read and looks better in my opinion.
